@@ -152,6 +152,7 @@ if (sum(Y^2)<1e-10){
 	B2=NULL
 	C1=NULL
 	C2=NULL
+    ev=NULL
 } else{
 	cat("If you want to standardize 'variables', type '1':",fill=TRUE)
 	cc=scan("",n=1)
@@ -171,6 +172,7 @@ if (sum(Y^2)<1e-10){
 	}
 }
 
+if (sum(Y^2)>1e-10){
 SVD=svd(Y)		 # P for rows  Q for columns
 ev=SVD$d^2
 rr=length(ev)
@@ -306,6 +308,7 @@ if (identical(C1,NULL)==FALSE){
 	colnames(C1)=labComp
 	colnames(C2)=labComp
 }
+}
 
 out=list()
 out$Y=Y
